from .aircontrol import AirControl
from .alicejapan import AliceJapan
from .aroma import Aroma
from .attackers import Attackers
from .auroraproject import AuroraProject
from .befree import BeFree
from .bi import Bi
from .bigmorkal import BigMorkal
from .caribbeancom import Caribbeancom
from .deeps import Deeps
from .dmm import DMM
from .heyzo import Heyzo
from .ideapocket import IdeaPocket
from .javlibrary import JAVLibrary
from .kmproduce import KMProduce
from .maxa import MaxA
from .mgstage import MGStage
from .onepondo import OnePondo
from .r18 import R18
from .s1 import S1
from .sod import SOD
from .tenmusume import TenMusume

__version__ = "1.1.8"
